==> 0.0.50.tar.gz: lib/FeedBackScreenComponent.dart <==
/*
    Refer License for Terms & Conditions
 */
import 'package:bui_component/ButtonsComponent/buttonComponent.dart';
import 'package:flutter/material.dart';
import 'package:flutter_rating_bar/flutter_rating_bar.dart';

import 'Constants/AppColors.dart';
import 'Constants/AppStrings.dart';
import 'Constants/fontFamily.dart';
import 'Constants/fontSize.dart';
import 'Utils/SystemUtils.dart';

class FeedBackScreenComponent extends StatefulWidget {
  Color themeColor;
  Color okayBtnColor;
  Color cancelBtnColor;
  Function(double s) initRating;
  final productController;
  double initRatingValue;
  final nameController;
  final emailController;
  final GlobalKey formKey;

  Function() ratingItemBuilder;
  Function() onOkayFunction;
  Function() onCancelFunction;
  Widget onOkayButton;
  Widget onCancelButton;

  FeedBackScreenComponent({
    this.themeColor,
    this.okayBtnColor,
    this.cancelBtnColor,
    this.initRatingValue,
    @required this.initRating,
    @required this.productController,
    @required this.nameController,
    @required this.emailController,
    @required this.formKey,
    @required this.onOkayButton,
    @required this.onCancelButton,
    this.ratingItemBuilder,
    @required this.onOkayFunction,
    @required this.onCancelFunction,
  });

  @override
  _FeedBackScreenComponentState createState() =>
      _FeedBackScreenComponentState();
}

class _FeedBackScreenComponentState extends State<FeedBackScreenComponent> {
  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        backgroundColor: widget.themeColor ?? AppColors.APP_COLOR_PRIMARY,
        title: Text(
          AppStrings.FEED_BACK,
          style: TextStyle(fontWeight: FontWeight.bold),
        ),
      ),
      body: ListView(
        children: [
          Container(
            padding: EdgeInsets.all(20),
            child: Column(
              crossAxisAlignment: CrossAxisAlignment.start,
              mainAxisAlignment: MainAxisAlignment.start,
              children: [
                Container(
                    padding: EdgeInsets.only(left: 10, bottom: 10),
                    child: Text(
                      AppStrings.RATE_THIS_PRODUCT,
                      style: TextStyle(
                          fontWeight: FontWeight.normal,
                          color: AppColors.textColor,
                          fontSize: FontSize.FONT_13),
                    )),
                RatingBar.builder(
                  initialRating: widget.initRatingValue ?? 0,
                  minRating: 0,
                  direction: Axis.horizontal,
                  itemCount: 5,
                  itemPadding: EdgeInsets.symmetric(horizontal: 4.0),
                  glow: true,
                  unratedColor: AppColors.halfWhite,
                  wrapAlignment: WrapAlignment.start,
                  itemBuilder: (context, index) {
                    return widget.ratingItemBuilder ??
                        Icon(
                          Icons.star,
                          color:
                              widget.themeColor ?? AppColors.APP_COLOR_PRIMARY,
                        );
                    //return callEmojiRatingBar(index);
                  },
                  onRatingUpdate: (rating) {
                    //rating);

                    setState(() {
                      widget.initRating(rating);
                    });
                  },
                ),

                Form(
                  key: widget.formKey,
                  autovalidateMode: AutovalidateMode.always,
                  child: Column(
                    crossAxisAlignment: CrossAxisAlignment.start,
                    mainAxisAlignment: MainAxisAlignment.start,
                    children: [
                      Container(
                          padding:
                              EdgeInsets.only(left: 10, bottom: 5, top: 17),
                          child: Text(
                            AppStrings.REVIEW_THIS_PRODUCT,
                            style: TextStyle(
                                fontWeight: FontWeight.normal,
                                color: AppColors.textColor,
                                fontSize: FontSize.FONT_13),
                          )),
                      //Review this product text filed
                      Container(
                        padding: EdgeInsets.only(
                          left: 10,
                          bottom: 10,
                        ),
                        child: TextFormField(
                          controller: widget.productController,
                          decoration: new InputDecoration(
                            contentPadding: new EdgeInsets.symmetric(
                                vertical: 40.0, horizontal: 10.0),
                            hintText: AppStrings.REVIEW_THIS_PRODUCT,
                            hintStyle: TextStyle(fontFamily: FontFamily.Gilroy),
                            fillColor: AppColors.appWhite,
                            focusedBorder: OutlineInputBorder(
                              borderRadius: BorderRadius.circular(7.0),
                              borderSide: BorderSide(
                                  color: AppColors.halfWhite, width: 2),
                            ),
                            enabledBorder: OutlineInputBorder(
                              borderRadius: BorderRadius.circular(7.0),
                              borderSide: BorderSide(
                                color: AppColors.halfWhite,
                                width: 2.0,
                              ),
                            ),
                            errorBorder: OutlineInputBorder(
                              borderRadius: BorderRadius.circular(7.0),
                              borderSide: BorderSide(
                                color: AppColors.errorWarning,
                                width: 2.0,
                              ),
                            ),
                            border: OutlineInputBorder(
                              borderRadius: BorderRadius.circular(7.0),
                              borderSide: BorderSide(
                                color: AppColors.errorWarning,
                                width: 2.0,
                              ),
                            ),
                          ),
                          validator: (val) {
                            if (val.length == 0) {
                              return AppStrings.REVIEW_CANNOT_BE_EMPTY;
                            } else {
                              return null;
                            }
                          },
                          keyboardType: TextInputType.text,
                          style: new TextStyle(
                            fontFamily: FontFamily.Poppins,
                            color: widget.themeColor ??
                                AppColors.APP_COLOR_PRIMARY,
                          ),
                        ),
                      ),

                      //Name
                      Container(
                          padding:
                              EdgeInsets.only(left: 10, bottom: 5, top: 17),
                          child: Text(
                            AppStrings.NAME,
                            style: TextStyle(
                                fontWeight: FontWeight.normal,
                                color: AppColors.textColor,
                                fontSize: FontSize.FONT_13),
                          )),
                      //Name Text Field
                      Container(
                        padding: EdgeInsets.only(
                          left: 10,
                          bottom: 10,
                        ),
                        child: TextFormField(
                          controller: widget.nameController,
                          decoration: new InputDecoration(
                            contentPadding: new EdgeInsets.symmetric(
                                vertical: 10.0, horizontal: 10.0),
                            hintText: AppStrings.NAME,
                            hintStyle: TextStyle(fontFamily: FontFamily.Gilroy),
                            fillColor: AppColors.appWhite,
                            focusedBorder: OutlineInputBorder(
                              borderRadius: BorderRadius.circular(7.0),
                              borderSide: BorderSide(
                                  color: AppColors.halfWhite, width: 2),
                            ),
                            enabledBorder: OutlineInputBorder(
                              borderRadius: BorderRadius.circular(7.0),
                              borderSide: BorderSide(
                                color: AppColors.halfWhite,
                                width: 2.0,
                              ),
                            ),
                            errorBorder: OutlineInputBorder(
                              borderRadius: BorderRadius.circular(7.0),
                              borderSide: BorderSide(
                                color: AppColors.errorWarning,
                                width: 2.0,
                              ),
                            ),
                            border: OutlineInputBorder(
                              borderRadius: BorderRadius.circular(7.0),
                              borderSide: BorderSide(
                                color: AppColors.errorWarning,
                                width: 2.0,
                              ),
                            ),
                          ),
                          validator: (val) {
                            if (val.length == 0) {
                              return AppStrings.NAME_MUST_BE_ENTER;
                            } else {
                              return null;
                            }
                          },
                          keyboardType: TextInputType.text,
                          style: new TextStyle(
                            fontFamily: FontFamily.Poppins,
                            color: widget.themeColor ??
                                AppColors.APP_COLOR_PRIMARY,
                          ),
                        ),
                      ),
                      //Email
                      Container(
                          padding:
                              EdgeInsets.only(left: 10, bottom: 5, top: 17),
                          child: Text(
                            AppStrings.EMAIL,
                            style: TextStyle(
                                fontWeight: FontWeight.normal,
                                color: AppColors.textColor,
                                fontSize: FontSize.FONT_13),
                          )),
                      //Email Text Field
                      Container(
                        padding: EdgeInsets.only(
                          left: 10,
                          bottom: 10,
                        ),
                        child: TextFormField(
                          controller: widget.emailController,
                          decoration: new InputDecoration(
                            contentPadding: new EdgeInsets.symmetric(
                                vertical: 10.0, horizontal: 10.0),
                            hintText: AppStrings.EMAIL,
                            hintStyle: TextStyle(fontFamily: FontFamily.Gilroy),
                            fillColor: AppColors.appWhite,
                            focusedBorder: OutlineInputBorder(
                              borderRadius: BorderRadius.circular(7.0),
                              borderSide: BorderSide(
                                  color: AppColors.halfWhite, width: 2),
                            ),
                            enabledBorder: OutlineInputBorder(
                              borderRadius: BorderRadius.circular(7.0),
                              borderSide: BorderSide(
                                color: AppColors.halfWhite,
                                width: 2.0,
                              ),
                            ),
                            errorBorder: OutlineInputBorder(
                              borderRadius: BorderRadius.circular(7.0),
                              borderSide: BorderSide(
                                color: AppColors.errorWarning,
                                width: 2.0,
                              ),
                            ),
                            border: OutlineInputBorder(
                              borderRadius: BorderRadius.circular(7.0),
                              borderSide: BorderSide(
                                color: AppColors.errorWarning,
                                width: 2.0,
                              ),
                            ),
                          ),
                          validator: (val) {
                            if (val.length == 0) {
                              return AppStrings.EMAIL_CANNOT_BE_EMPTY;
                            } else if (!SystemUtils.hasMatchEmail(val)) {
                              return AppStrings.INVALID_EMAIL;
                            } else {
                              return null;
                            }
                          },
                          keyboardType: TextInputType.emailAddress,
                          style: new TextStyle(
                            fontFamily: FontFamily.Poppins,
                            color: widget.themeColor ??
                                AppColors.APP_COLOR_PRIMARY,
                          ),
                        ),
                      ),
                    ],
                  ),
                ),
                //Review this product

                Container(
                  padding:
                      EdgeInsets.only(left: 10, bottom: 5, top: 17, right: 10),
                  child: Row(
                    crossAxisAlignment: CrossAxisAlignment.start,
                    mainAxisAlignment: MainAxisAlignment.spaceAround,
                    children: [
                      widget.onCancelButton ??
                          Button.mini(
                            width: 90,
                            buttonSize: ButtonSize.medium,
                            buttonType: ButtonType.cancel,
                            btnColor:
                                widget.cancelBtnColor ?? AppColors.LIGHT_GREY,
                            btnTextColor: widget.themeColor ??
                                AppColors.APP_COLOR_PRIMARY,
                            elevation: 10,
                            onPressed: () {
                              widget.onCancelFunction();
                            },
                          ),
                      widget.onOkayButton ??
                          Button.mini(
                            width: 90,
                            elevation: 10,
                            buttonSize: ButtonSize.medium,
                            buttonType: ButtonType.okay,
                            btnColor: widget.okayBtnColor ??
                                AppColors.APP_COLOR_PRIMARY,
                            btnTextColor: AppColors.LIGHT_GREY,
                            onPressed: () {
                              widget.onOkayFunction();
                            },
                          )
                    ],
                  ),
                ),
              ],
            ),
          ),
        ],
      ),
    );
  }
}

==> 0.0.63.tar.gz: lib/FeedBackScreenComponent.dart <==
/*
    Refer License for Terms & Conditions
 */
import 'package:bui_component/ButtonsComponent/buttonComponent.dart';
import 'package:flutter/material.dart';
import 'package:flutter_rating_bar/flutter_rating_bar.dart';

import 'Constants/AppColors.dart';
import 'Constants/AppStrings.dart';
import 'Constants/fontFamily.dart';
import 'Constants/fontSize.dart';
import 'Utils/SystemUtils.dart';

class FeedBackScreenComponent extends StatefulWidget {
  Color themeColor;
  Color okayBtnColor;
  Color cancelBtnColor;
  Function(double s) initRating;
  final productController;
  double initRatingValue;
  final nameController;
  final emailController;
  final GlobalKey formKey;

  Function() ratingItemBuilder;
  Function() onOkayFunction;
  Function() onCancelFunction;
  Widget onOkayButton;
  Widget onCancelButton;

  FeedBackScreenComponent({
    this.themeColor,
    this.okayBtnColor,
    this.cancelBtnColor,
    this.initRatingValue,
     this.initRating,
     this.productController,
     this.nameController,
     this.emailController,
     this.formKey,
     this.onOkayButton,
     this.onCancelButton,
    this.ratingItemBuilder,
     this.onOkayFunction,
     this.onCancelFunction,
  });

  @override
  _FeedBackScreenComponentState createState() =>
      _FeedBackScreenComponentState();
}

class _FeedBackScreenComponentState extends State<FeedBackScreenComponent> {
  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        backgroundColor: widget.themeColor ?? AppColors.APP_COLOR_PRIMARY,
        title: Text(
          AppStrings.FEED_BACK,
          style: TextStyle(fontWeight: FontWeight.bold),
        ),
      ),
      body: ListView(
        children: [
          Container(
            padding: EdgeInsets.all(20),
            child: Column(
              crossAxisAlignment: CrossAxisAlignment.start,
              mainAxisAlignment: MainAxisAlignment.start,
              children: [
                Container(
                    padding: EdgeInsets.only(left: 10, bottom: 10),
                    child: Text(
                      AppStrings.RATE_THIS_PRODUCT,
                      style: TextStyle(
                          fontWeight: FontWeight.normal,
                          color: AppColors.textColor,
                          fontSize: FontSize.FONT_13),
                    )),
                RatingBar.builder(
                  initialRating: widget.initRatingValue ?? 0,
                  minRating: 0,
                  direction: Axis.horizontal,
                  itemCount: 5,
                  itemPadding: EdgeInsets.symmetric(horizontal: 4.0),
                  glow: true,
                  unratedColor: AppColors.halfWhite,
                  wrapAlignment: WrapAlignment.start,
                  itemBuilder: (context, index) {
                    return widget.ratingItemBuilder ??
                        Icon(
                          Icons.star,
                          color:
                              widget.themeColor ?? AppColors.APP_COLOR_PRIMARY,
                        );
                    //return callEmojiRatingBar(index);
                  },
                  onRatingUpdate: (rating) {
                    //rating);

                    setState(() {
                      widget.initRating(rating);
                    });
                  },
                ),

                Form(
                  key: widget.formKey,
                  autovalidateMode: AutovalidateMode.always,
                  child: Column(
                    crossAxisAlignment: CrossAxisAlignment.start,
                    mainAxisAlignment: MainAxisAlignment.start,
                    children: [
                      Container(
                          padding:
                              EdgeInsets.only(left: 10, bottom: 5, top: 17),
                          child: Text(
                            AppStrings.REVIEW_THIS_PRODUCT,
                            style: TextStyle(
                                fontWeight: FontWeight.normal,
                                color: AppColors.textColor,
                                fontSize: FontSize.FONT_13),
                          )),
                      //Review this product text filed
                      Container(
                        padding: EdgeInsets.only(
                          left: 10,
                          bottom: 10,
                        ),
                        child: TextFormField(
                          controller: widget.productController,
                          decoration: new InputDecoration(
                            contentPadding: new EdgeInsets.symmetric(
                                vertical: 40.0, horizontal: 10.0),
                            hintText: AppStrings.REVIEW_THIS_PRODUCT,
                            hintStyle: TextStyle(fontFamily: FontFamily.Gilroy),
                            fillColor: AppColors.appWhite,
                            focusedBorder: OutlineInputBorder(
                              borderRadius: BorderRadius.circular(7.0),
                              borderSide: BorderSide(
                                  color: AppColors.halfWhite, width: 2),
                            ),
                            enabledBorder: OutlineInputBorder(
                              borderRadius: BorderRadius.circular(7.0),
                              borderSide: BorderSide(
                                color: AppColors.halfWhite,
                                width: 2.0,
                              ),
                            ),
                            errorBorder: OutlineInputBorder(
                              borderRadius: BorderRadius.circular(7.0),
                              borderSide: BorderSide(
                                color: AppColors.errorWarning,
                                width: 2.0,
                              ),
                            ),
                            border: OutlineInputBorder(
                              borderRadius: BorderRadius.circular(7.0),
                              borderSide: BorderSide(
                                color: AppColors.errorWarning,
                                width: 2.0,
                              ),
                            ),
                          ),
                          validator: (val) {
                            if (val.length == 0) {
                              return AppStrings.REVIEW_CANNOT_BE_EMPTY;
                            } else {
                              return null;
                            }
                          },
                          keyboardType: TextInputType.text,
                          style: new TextStyle(
                            fontFamily: FontFamily.Poppins,
                            color: widget.themeColor ??
                                AppColors.APP_COLOR_PRIMARY,
                          ),
                        ),
                      ),

                      //Name
                      Container(
                          padding:
                              EdgeInsets.only(left: 10, bottom: 5, top: 17),
                          child: Text(
                            AppStrings.NAME,
                            style: TextStyle(
                                fontWeight: FontWeight.normal,
                                color: AppColors.textColor,
                                fontSize: FontSize.FONT_13),
                          )),
                      //Name Text Field
                      Container(
                        padding: EdgeInsets.only(
                          left: 10,
                          bottom: 10,
                        ),
                        child: TextFormField(
                          controller: widget.nameController,
                          decoration: new InputDecoration(
                            contentPadding: new EdgeInsets.symmetric(
                                vertical: 10.0, horizontal: 10.0),
                            hintText: AppStrings.NAME,
                            hintStyle: TextStyle(fontFamily: FontFamily.Gilroy),
                            fillColor: AppColors.appWhite,
                            focusedBorder: OutlineInputBorder(
                              borderRadius: BorderRadius.circular(7.0),
                              borderSide: BorderSide(
                                  color: AppColors.halfWhite, width: 2),
                            ),
                            enabledBorder: OutlineInputBorder(
                              borderRadius: BorderRadius.circular(7.0),
                              borderSide: BorderSide(
                                color: AppColors.halfWhite,
                                width: 2.0,
                              ),
                            ),
                            errorBorder: OutlineInputBorder(
                              borderRadius: BorderRadius.circular(7.0),
                              borderSide: BorderSide(
                                color: AppColors.errorWarning,
                                width: 2.0,
                              ),
                            ),
                            border: OutlineInputBorder(
                              borderRadius: BorderRadius.circular(7.0),
                              borderSide: BorderSide(
                                color: AppColors.errorWarning,
                                width: 2.0,
                              ),
                            ),
                          ),
                          validator: (val) {
                            if (val.length == 0) {
                              return AppStrings.NAME_MUST_BE_ENTER;
                            } else {
                              return null;
                            }
                          },
                          keyboardType: TextInputType.text,
                          style: new TextStyle(
                            fontFamily: FontFamily.Poppins,
                            color: widget.themeColor ??
                                AppColors.APP_COLOR_PRIMARY,
                          ),
                        ),
                      ),
                      //Email
                      Container(
                          padding:
                              EdgeInsets.only(left: 10, bottom: 5, top: 17),
                          child: Text(
                            AppStrings.EMAIL,
                            style: TextStyle(
                                fontWeight: FontWeight.normal,
                                color: AppColors.textColor,
                                fontSize: FontSize.FONT_13),
                          )),
                      //Email Text Field
                      Container(
                        padding: EdgeInsets.only(
                          left: 10,
                          bottom: 10,
                        ),
                        child: TextFormField(
                          controller: widget.emailController,
                          decoration: new InputDecoration(
                            contentPadding: new EdgeInsets.symmetric(
                                vertical: 10.0, horizontal: 10.0),
                            hintText: AppStrings.EMAIL,
                            hintStyle: TextStyle(fontFamily: FontFamily.Gilroy),
                            fillColor: AppColors.appWhite,
                            focusedBorder: OutlineInputBorder(
                              borderRadius: BorderRadius.circular(7.0),
                              borderSide: BorderSide(
                                  color: AppColors.halfWhite, width: 2),
                            ),
                            enabledBorder: OutlineInputBorder(
                              borderRadius: BorderRadius.circular(7.0),
                              borderSide: BorderSide(
                                color: AppColors.halfWhite,
                                width: 2.0,
                              ),
                            ),
                            errorBorder: OutlineInputBorder(
                              borderRadius: BorderRadius.circular(7.0),
                              borderSide: BorderSide(
                                color: AppColors.errorWarning,
                                width: 2.0,
                              ),
                            ),
                            border: OutlineInputBorder(
                              borderRadius: BorderRadius.circular(7.0),
                              borderSide: BorderSide(
                                color: AppColors.errorWarning,
                                width: 2.0,
                              ),
                            ),
                          ),
                          validator: (val) {
                            if (val.length == 0) {
                              return AppStrings.EMAIL_CANNOT_BE_EMPTY;
                            } else if (!SystemUtils.hasMatchEmail(val)) {
                              return AppStrings.INVALID_EMAIL;
                            } else {
                              return null;
                            }
                          },
                          keyboardType: TextInputType.emailAddress,
                          style: new TextStyle(
                            fontFamily: FontFamily.Poppins,
                            color: widget.themeColor ??
                                AppColors.APP_COLOR_PRIMARY,
                          ),
                        ),
                      ),
                    ],
                  ),
                ),
                //Review this product

                Container(
                  padding:
                      EdgeInsets.only(left: 10, bottom: 5, top: 17, right: 10),
                  child: Row(
                    crossAxisAlignment: CrossAxisAlignment.start,
                    mainAxisAlignment: MainAxisAlignment.spaceAround,
                    children: [
                      widget.onCancelButton ??
                          Button.mini(
                            width: 90,
                            buttonSize: ButtonSize.medium,
                            buttonType: ButtonType.cancel,
                            btnColor:
                                widget.cancelBtnColor ?? AppColors.LIGHT_GREY,
                            btnTextColor: widget.themeColor ??
                                AppColors.APP_COLOR_PRIMARY,
                            elevation: 10,
                            onPressed: () {
                              widget.onCancelFunction();
                            },
                          ),
                      widget.onOkayButton ??
                          Button.mini(
                            width: 90,
                            elevation: 10,
                            buttonSize: ButtonSize.medium,
                            buttonType: ButtonType.okay,
                            btnColor: widget.okayBtnColor ??
                                AppColors.APP_COLOR_PRIMARY,
                            btnTextColor: AppColors.LIGHT_GREY,
                            onPressed: () {
                              widget.onOkayFunction();
                            },
                          )
                    ],
                  ),
                ),
              ],
            ),
          ),
        ],
      ),
    );
  }
}
